@@ -15,7 +15,7 @@
 #include "eckit/runtime/Main.h"
 #include "eckit/utils/Tokenizer.h"
 
-#include "metkit/mars/MarsExpension.h"
+#include "metkit/mars/MarsExpansion.h"
 #include "metkit/mars/MarsRequest.h"
 
 #include "fdb5/api/FDB.h"
@@ -82,7 +82,7 @@ public:
     void expand() {
         bool inherit = false;
         bool strict  = true;
-        metkit::mars::MarsExpension expand(inherit, strict);
+        metkit::mars::MarsExpansion expand(inherit, strict);
         request_ = expand.expand(request_);
     }
     const metkit::mars::MarsRequest request() const { return request_; }
@@ -341,8 +341,6 @@ int wrapApiFunction(FN f) {
         }
         return FDB_ERROR_UNKNOWN_EXCEPTION;
     }
-
-    ASSERT(false);
 }
 
 }  // namespace
