@@ -48,6 +48,32 @@ using ListAsyncIterator = APIAsyncIterator<ListElement>;
 
 //----------------------------------------------------------------------------------------------------------------------
 
+/// KeyStore is a specialised helper class used for deduplication of return ListElements.
+///
+/// Previously a std::unordered_map<Key> was used, but this significantly duplicates the components of the first/second
+/// level of the key, and uses an enormous amount of memory allocated as the components of the relevant Key objects
+/// (std::vector, std::pair and std::string objects). Significant computational resources was used stringising and
+/// hashing these objects.
+///
+/// We now store a hierarchy of key components, such that the (rarely changing) first two levels of the key are only
+/// stored once for each set of values. The actual values stored are the fingerprints in the format
+/// <value>:<value>:... as constructed in conjunction with the schema - which are significantly smaller than the
+/// Key objects, and have the advantage of being a single allocation.
+///
+/// The introduction of this class eliminates a class of out-of-memory kill events, and improves the performance of
+/// listing the contents of the FDB
+
+class KeyStore {
+
+    std::unordered_map<std::string, std::unordered_map<std::string, std::unordered_set<std::string>>> fingerprints_;
+
+public:
+
+    bool tryInsert(const std::array<Key, 3>& keyParts);
+};
+
+//----------------------------------------------------------------------------------------------------------------------
+
 class ListIterator : public APIIterator<ListElement> {
 public:
 
@@ -64,7 +90,7 @@ public:
 
 private:
 
-    std::unordered_set<Key> seenKeys_;
+    KeyStore seenKeys_;
     bool deduplicate_;
 };
 
