@@ -13,14 +13,14 @@
 #include "eckit/config/Resource.h"
 #include "eckit/serialisation/MemoryStream.h"
 
-#include "fdb5/api/helpers/ControlIterator.h"
 #include "fdb5/LibFdb5.h"
+#include "fdb5/api/helpers/ControlIterator.h"
 #include "fdb5/database/DatabaseNotFoundException.h"
 
 #include "fdb5/daos/DaosCatalogue.h"
+#include "fdb5/daos/DaosIndex.h"
 #include "fdb5/daos/DaosName.h"
 #include "fdb5/daos/DaosSession.h"
-#include "fdb5/daos/DaosIndex.h"
 #include "fdb5/daos/DaosWipeVisitor.h"
 
 // using namespace eckit;
@@ -36,10 +36,10 @@ DaosCatalogue::DaosCatalogue(const Key& key, const fdb5::Config& config) :
     //   FileSpaceTables to determine root_pool_name_ according to key
     //   and using DbPathNamerTables to determine db_cont_name_ according
     //   to key
-
 }
 
-DaosCatalogue::DaosCatalogue(const eckit::URI& uri, const ControlIdentifiers& controlIdentifiers, const fdb5::Config& config) :
+DaosCatalogue::DaosCatalogue(const eckit::URI& uri, const ControlIdentifiers& controlIdentifiers,
+                             const fdb5::Config& config) :
     CatalogueImpl(Key(), controlIdentifiers, config), DaosCommon(config, "catalogue", uri) {
 
     // Read the real DB key into the DB base object
@@ -51,36 +51,29 @@ DaosCatalogue::DaosCatalogue(const eckit::URI& uri, const ControlIdentifiers& co
 
         std::vector<char> data;
         eckit::MemoryStream ms = db_kv.getMemoryStream(data, "key", "DB kv");
-        dbKey_ = fdb5::Key(ms);
-
-    } catch (fdb5::DaosEntityNotFoundException& e) {
-
-        throw fdb5::DatabaseNotFoundException(
-            std::string("DaosCatalogue database not found ") +
-            "(pool: '" + pool_ + "', container: '" + db_cont_ + "')"
-        );
-
+        dbKey_                 = fdb5::Key(ms);
     }
+    catch (fdb5::DaosEntityNotFoundException& e) {
 
+        throw fdb5::DatabaseNotFoundException(std::string("DaosCatalogue database not found ") + "(pool: '" + pool_ +
+                                              "', container: '" + db_cont_ + "')");
+    }
 }
 
 bool DaosCatalogue::exists() const {
 
     fdb5::DaosKeyValueName catalogue_kv_name{pool_, db_cont_, catalogue_kv_};
     return catalogue_kv_name.exists();
-
 }
 
 eckit::URI DaosCatalogue::uri() const {
 
     return fdb5::DaosName{db_kv_->poolName(), db_kv_->containerName()}.URI();
-
 }
 
 const Schema& DaosCatalogue::schema() const {
 
     return schema_;
-
 }
 
 const Rule& DaosCatalogue::rule() const {
@@ -107,10 +100,10 @@ void DaosCatalogue::loadSchema() {
     schema_.load(stream);
 
     rule_ = &schema_.matchingRule(dbKey_);
-
 }
 
-WipeVisitor* DaosCatalogue::wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out, bool doit, bool porcelain, bool unsafeWipeAll) const {
+WipeVisitor* DaosCatalogue::wipeVisitor(const Store& store, const metkit::mars::MarsRequest& request, std::ostream& out,
+                                        bool doit, bool porcelain, bool unsafeWipeAll) const {
     return new DaosWipeVisitor(*this, store, request, out, doit, porcelain, unsafeWipeAll);
 }
 
@@ -132,7 +125,8 @@ std::vector<Index> DaosCatalogue::indexes(bool) const {
 
         /// @todo: document these well. Single source these reserved values.
         ///    Ensure where appropriate that user-provided keys do not collide.
-        if (key == "schema" || key == "key") continue;
+        if (key == "schema" || key == "key")
+            continue;
 
         /// @note: performed RPCs:
         /// - db kv get index location size (daos_kv_get without a buffer)
@@ -147,10 +141,10 @@ std::vector<Index> DaosCatalogue::indexes(bool) const {
         /// - index kv open (daos_kv_open)
         /// - index kv get size (daos_kv_get without a buffer)
         /// - index kv get key (daos_kv_get)
-        /// @note: the following three lines intend to check whether the index kv exists 
+        /// @note: the following three lines intend to check whether the index kv exists
         ///   or not. The DaosKeyValue constructor calls kv open, which always succeeds,
         ///   so it is not useful on its own to check whether the index KV existed or not.
-        ///   Instead, presence of a "key" key in the KV is used to determine if the index 
+        ///   Instead, presence of a "key" key in the KV is used to determine if the index
         ///   KV existed.
         fdb5::DaosKeyValue index_kv{s, index_kv_name};
         std::optional<fdb5::Key> index_key;
@@ -158,17 +152,16 @@ std::vector<Index> DaosCatalogue::indexes(bool) const {
             std::vector<char> data;
             eckit::MemoryStream ms = index_kv.getMemoryStream(data, "key", "index KV");
             index_key.emplace(ms);
-        } catch (fdb5::DaosEntityNotFoundException& e) {
-            continue; /// @note: the index_kv may not exist after a failed wipe
+        }
+        catch (fdb5::DaosEntityNotFoundException& e) {
+            continue;  /// @note: the index_kv may not exist after a failed wipe
             /// @todo: the index_kv may exist even if it does not have the "key" key
         }
 
         res.push_back(Index(new fdb5::DaosIndex(index_key.value(), *this, index_kv_name, false)));
-
     }
 
     return res;
-    
 }
 
 std::string DaosCatalogue::type() const {
@@ -182,10 +175,10 @@ void DaosCatalogue::remove(const fdb5::DaosNameBase& n, std::ostream& logAlways,
 
     logVerbose << "Removing " << (n.hasOID() ? "KV" : "container") << ": ";
     logAlways << n.URI() << std::endl;
-    if (doit) n.destroy();
-
+    if (doit)
+        n.destroy();
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
