@@ -41,7 +41,8 @@ protected:  // methods
 
     bool selectDatabase(const Key& dbKey, const Key&) override;
 
-    bool selectIndex(const Key& idxKey, const Key&) override;
+    bool selectIndex(const Key& idxKey) override;
+    bool createIndex(const Key& idxKey, size_t datumKeySize) override;
 
     virtual void checkMissingKeys(const Key& fullKey) const;
 
