@@ -25,8 +25,7 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-class DataStatsContent : public eckit::Counted,
-                         public eckit::Statistics {
+class DataStatsContent : public eckit::Counted, public eckit::Statistics {
 public:
 
     ~DataStatsContent() override;
@@ -34,7 +33,6 @@ public:
     virtual void add(const DataStatsContent&) = 0;
 
     virtual void report(std::ostream& out, const char* indent) const = 0;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -43,7 +41,7 @@ public:
 
 class DataStats {
 
-public: // methods
+public:  // methods
 
     DataStats();
     DataStats(DataStatsContent*);
@@ -58,26 +56,27 @@ public: // methods
 
     void report(std::ostream& out, const char* indent = "") const;
 
-//    template <class T>
-//    T& as() {
-//        return dynamic_cast<T&>(*content_);
-//    }
+    //    template <class T>
+    //    T& as() {
+    //        return dynamic_cast<T&>(*content_);
+    //    }
 
-private: // methods
+private:  // methods
 
     void print(std::ostream&) const;
 
     friend std::ostream& operator<<(std::ostream& s, const DataStats& o) {
-        o.print(s); return s;
+        o.print(s);
+        return s;
     }
 
-private: // members
+private:  // members
 
     DataStatsContent* content_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
