@@ -9,9 +9,9 @@
  */
 
 
-#include "eckit/memory/NonCopyable.h"
 #include "eckit/filesystem/PathName.h"
 #include "eckit/filesystem/URI.h"
+#include "eckit/memory/NonCopyable.h"
 #include "eckit/serialisation/Streamable.h"
 
 #ifndef fdb5_IndexLocation_H
@@ -23,28 +23,28 @@ namespace fdb5 {
 
 class IndexLocation : public eckit::Streamable {
 
-public: // methods
+public:  // methods
 
     IndexLocation();
     ~IndexLocation() override;
 
-//    virtual eckit::PathName path() const = 0;
+    //    virtual eckit::PathName path() const = 0;
     virtual eckit::URI uri() const = 0;
 
     virtual IndexLocation* clone() const = 0;
 
-private: // methods
+private:  // methods
 
     virtual void print(std::ostream& out) const = 0;
 
 
-protected: // For streamable
+protected:  // For streamable
 
     void encode(eckit::Stream&) const override = 0;
 
     static eckit::ClassSpec classSpec_;
 
-private: // friends
+private:  // friends
 
     friend std::ostream& operator<<(std::ostream& s, const IndexLocation& x) {
         x.print(s);
@@ -56,15 +56,15 @@ private: // friends
 
 class IndexLocationVisitor {
 
-public: // methods
+public:  // methods
 
     virtual ~IndexLocationVisitor();
 
-    virtual void operator() (const IndexLocation&) = 0;
+    virtual void operator()(const IndexLocation&) = 0;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}
+}  // namespace fdb5
 
-#endif // fdb5_IndexLocation_H
+#endif  // fdb5_IndexLocation_H
