@@ -19,21 +19,14 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Indexer::Indexer() :
-    pid_(::getpid()),
-    thread_(::pthread_self())
-{
+Indexer::Indexer() : pid_(::getpid()), thread_(::pthread_self()) {
     hostname_ = eckit::Main::hostname();
 }
 
-void Indexer::print(std::ostream& out) const
-{
-    out << "(host=" << hostname_
-        << ",pid=" << pid_
-        << ",thread=" << thread_
-        << ")";
+void Indexer::print(std::ostream& out) const {
+    out << "(host=" << hostname_ << ",pid=" << pid_ << ",thread=" << thread_ << ")";
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
