@@ -30,6 +30,7 @@ class MarsRequest;
 namespace fdb5 {
 
 class Rule;
+class RuleDatum;
 class Schema;
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -43,7 +44,8 @@ public:  // methods
     virtual ~WriteVisitor() = default;
 
     virtual bool selectDatabase(const Key& dbKey, const Key& fullKey) = 0;
-    virtual bool selectIndex(const Key& idxKey, const Key& fullKey)   = 0;
+    virtual bool selectIndex(const Key& idxKey)                       = 0;
+    virtual bool createIndex(const Key& idxKey, size_t datumKeySize)  = 0;
     virtual bool selectDatum(const Key& datumKey, const Key& fullKey) = 0;
 
     // Once we have selected a database, return its schema. Used for further iteration.
