@@ -8,33 +8,32 @@
  * does it submit to any jurisdiction.
  */
 
-#include "eckit/io/rados/RadosReadHandle.h"
 #include "fdb5/rados/RadosFieldLocation.h"
+#include "eckit/io/rados/RadosReadHandle.h"
 #include "fdb5/LibFdb5.h"
 #include "fdb5/io/SingleGribMungePartFileHandle.h"
 
 namespace fdb5 {
 
-::eckit::ClassSpec RadosFieldLocation::classSpec_ = {&FieldLocation::classSpec(), "RadosFieldLocation",};
+::eckit::ClassSpec RadosFieldLocation::classSpec_ = {
+    &FieldLocation::classSpec(),
+    "RadosFieldLocation",
+};
 ::eckit::Reanimator<RadosFieldLocation> RadosFieldLocation::reanimator_;
 
 //----------------------------------------------------------------------------------------------------------------------
 
-RadosFieldLocation::RadosFieldLocation(const eckit::PathName path, eckit::Offset offset, eckit::Length length ) :
-        FieldLocation(eckit::URI("rados", path), offset, length) {}
+RadosFieldLocation::RadosFieldLocation(const eckit::PathName path, eckit::Offset offset, eckit::Length length) :
+    FieldLocation(eckit::URI("rados", path), offset, length) {}
 
-RadosFieldLocation::RadosFieldLocation(const eckit::URI &uri) :
-        FieldLocation(uri) {}
+RadosFieldLocation::RadosFieldLocation(const eckit::URI& uri) : FieldLocation(uri) {}
 
-RadosFieldLocation::RadosFieldLocation(const eckit::URI &uri, eckit::Offset offset, eckit::Length length ) :
-        FieldLocation(uri, offset, length) {
-}
+RadosFieldLocation::RadosFieldLocation(const eckit::URI& uri, eckit::Offset offset, eckit::Length length) :
+    FieldLocation(uri, offset, length) {}
 
-RadosFieldLocation::RadosFieldLocation(const RadosFieldLocation& rhs) :
-    FieldLocation(rhs.uri_) {}
+RadosFieldLocation::RadosFieldLocation(const RadosFieldLocation& rhs) : FieldLocation(rhs.uri_) {}
 
-RadosFieldLocation::RadosFieldLocation(eckit::Stream& s) :
-    FieldLocation(s) {}
+RadosFieldLocation::RadosFieldLocation(eckit::Stream& s) : FieldLocation(s) {}
 
 
 std::shared_ptr<const FieldLocation> RadosFieldLocation::make_shared() const {
@@ -47,11 +46,11 @@ eckit::DataHandle* RadosFieldLocation::dataHandle() const {
     return g;
 }
 
-eckit::DataHandle *RadosFieldLocation::dataHandle(const Key& remapKey) const {
+eckit::DataHandle* RadosFieldLocation::dataHandle(const Key& remapKey) const {
     return new SingleGribMungePartFileHandle(path(), offset(), length(), remapKey);
 }
 
-void RadosFieldLocation::print(std::ostream &out) const {
+void RadosFieldLocation::print(std::ostream& out) const {
     out << "RadosFieldLocation[uri=" << uri_ << "]";
 }
 
@@ -59,7 +58,7 @@ void RadosFieldLocation::visit(FieldLocationVisitor& visitor) const {
     visitor(*this);
 }
 
-eckit::URI RadosFieldLocation::uri(const eckit::PathName &path) {
+eckit::URI RadosFieldLocation::uri(const eckit::PathName& path) {
     return eckit::URI("rados", path);
 }
 
@@ -67,4 +66,4 @@ static FieldLocationBuilder<RadosFieldLocation> builder("rados");
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
