@@ -25,6 +25,7 @@
 #include "eckit/types/FixedString.h"
 
 #include "fdb5/database/Index.h"
+#include "fdb5/database/Key.h"
 
 namespace fdb5 {
 
@@ -53,7 +54,7 @@ public:
     virtual void preload()                                         = 0;
 
 
-    static const std::string& defaultType();
+    static const std::string& defaultType(size_t keySize);
 };
 
 //----------------------------------------------------------------------------------------------------------------------
