@@ -16,18 +16,18 @@
 #define fdb5_RootManager_H
 
 #include "eckit/config/LocalConfiguration.h"
-#include "eckit/utils/Regex.h"
 #include "eckit/filesystem/PathName.h"
+#include "eckit/utils/Regex.h"
 
+#include "fdb5/api/helpers/ControlIterator.h"
 #include "fdb5/config/Config.h"
 #include "fdb5/toc/FileSpace.h"
-#include "fdb5/api/helpers/ControlIterator.h"
 
 namespace metkit {
 namespace mars {
-    class MarsRequest;
-}
+class MarsRequest;
 }
+}  // namespace metkit
 
 namespace fdb5 {
 
@@ -39,17 +39,17 @@ class DbPathNamer;
 
 typedef std::vector<fdb5::FileSpace> FileSpaceTable;
 
-class RootManager  {
+class RootManager {
 
-public: // methods
+public:  // methods
 
     RootManager(const Config& config);
 
     /// Uniquely selects a directory where the Key will be put or already exists
-    TocPath directory(const Key &key);
+    TocPath directory(const Key& key);
 
     /// Lists the roots that can be visited given a DB key
-    std::vector<eckit::PathName> allRoots(const Key& key);
+    // std::vector<eckit::PathName> allRoots(const Key& key);
 
     /// Lists the roots that can be visited given a DB key
     std::vector<eckit::PathName> visitableRoots(const Key& key);
@@ -64,16 +64,16 @@ public: // methods
 
     std::vector<std::string> possibleDbPathNames(const Key& key, const char* missing);
 
-protected: // methods
+protected:  // methods
 
     virtual FileSpaceTable fileSpaces();
     virtual std::vector<eckit::LocalConfiguration> getSpaceRoots(const eckit::LocalConfiguration& space) = 0;
 
-protected: // members
+protected:  // members
 
     std::vector<FileSpace> spacesTable_;
 
-private: // members
+private:  // members
 
     const std::vector<DbPathNamer>& dbPathNamers_;
     Config config_;
@@ -81,34 +81,28 @@ private: // members
 
 class CatalogueRootManager : public RootManager {
 
-public: // methods
+public:  // methods
 
-    CatalogueRootManager(const Config& config) :
-        RootManager(config) {
-        spacesTable_ = fileSpaces();
-    }
+    CatalogueRootManager(const Config& config) : RootManager(config) { spacesTable_ = fileSpaces(); }
 
-protected: // methods
+protected:  // methods
 
     std::vector<eckit::LocalConfiguration> getSpaceRoots(const eckit::LocalConfiguration& space) override;
 };
 
 class StoreRootManager : public RootManager {
 
-public: // methods
+public:  // methods
 
-    StoreRootManager(const Config& config) :
-        RootManager(config) {
-        spacesTable_ = fileSpaces();
-    }
+    StoreRootManager(const Config& config) : RootManager(config) { spacesTable_ = fileSpaces(); }
 
-protected: // methods
+protected:  // methods
 
     std::vector<eckit::LocalConfiguration> getSpaceRoots(const eckit::LocalConfiguration& space) override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
