@@ -19,14 +19,14 @@
 #include "fdb5/api/helpers/ControlIterator.h"
 #include "fdb5/database/Catalogue.h"
 #include "fdb5/database/Store.h"
+#include "fdb5/toc/RootManager.h"
 #include "fdb5/toc/TocCatalogue.h"
 #include "fdb5/toc/TocMoveVisitor.h"
-#include "fdb5/toc/RootManager.h"
 
 #include <dirent.h>
 #include <fdb5/LibFdb5.h>
-#include <sys/types.h>
 #include <sys/file.h>
+#include <sys/types.h>
 #include <cstring>
 
 using namespace eckit;
@@ -37,15 +37,10 @@ namespace fdb5 {
 
 // TODO: Warnings and errors form inside here back to the user.
 
-TocMoveVisitor::TocMoveVisitor(const TocCatalogue& catalogue,
-                               const Store& store,
-                               const metkit::mars::MarsRequest& request,
-                               const eckit::URI& dest,
+TocMoveVisitor::TocMoveVisitor(const TocCatalogue& catalogue, const Store& store,
+                               const metkit::mars::MarsRequest& request, const eckit::URI& dest,
                                eckit::Queue<MoveElement>& queue) :
-    MoveVisitor(request, dest),
-    catalogue_(catalogue),
-    store_(store),
-    queue_(queue) {}
+    MoveVisitor(request, dest), catalogue_(catalogue), store_(store), queue_(queue) {}
 
 TocMoveVisitor::~TocMoveVisitor() {}
 
@@ -60,10 +55,10 @@ bool TocMoveVisitor::visitDatabase(const Catalogue& catalogue) {
     DIR* dirp = ::opendir(catalogue_.basePath().c_str());
     struct dirent* dp;
     while ((dp = readdir(dirp)) != NULL) {
-        if (strstr( dp->d_name, ".index")) {
+        if (strstr(dp->d_name, ".index")) {
             eckit::PathName src_ = PathName(catalogue_.basePath()) / dp->d_name;
-            int fd = ::open(src_.asString().c_str(), O_RDWR);
-            if(::flock(fd, LOCK_EX)) {
+            int fd               = ::open(src_.asString().c_str(), O_RDWR);
+            if (::flock(fd, LOCK_EX)) {
                 std::stringstream ss;
                 ss << "Index file " << dp->d_name << " is locked";
                 throw eckit::UserError(ss.str(), Here());
@@ -77,13 +72,13 @@ bool TocMoveVisitor::visitDatabase(const Catalogue& catalogue) {
         eckit::PathName destPath = dest_.path();
 
         bool found = false;
-        
-        for (const eckit::PathName& root: CatalogueRootManager(catalogue_.config()).canMoveToRoots(catalogue_.key())) {
+
+        for (const eckit::PathName& root : CatalogueRootManager(catalogue_.config()).canMoveToRoots(catalogue_.key())) {
 
             if (root.sameAs(destPath)) {
                 eckit::PathName dest_db = destPath / catalogue_.basePath().baseName(true);
 
-                if(dest_db.exists()) {
+                if (dest_db.exists()) {
                     std::stringstream ss;
                     ss << "Target folder already exist!" << std::endl;
                     throw UserError(ss.str(), Here());
@@ -94,10 +89,12 @@ bool TocMoveVisitor::visitDatabase(const Catalogue& catalogue) {
         }
         if (!found) {
             std::stringstream ss;
-            ss << "Destination " << dest_ << " cannot be used to archive a DB with key: " << catalogue_.key() << std::endl;
+            ss << "Destination " << dest_ << " cannot be used to archive a DB with key: " << catalogue_.key()
+               << std::endl;
             throw eckit::UserError(ss.str(), Here());
         }
-    } else {
+    }
+    else {
         std::stringstream ss;
         ss << "Destination " << dest_ << " not supported." << std::endl;
         throw eckit::UserError(ss.str(), Here());
@@ -107,7 +104,7 @@ bool TocMoveVisitor::visitDatabase(const Catalogue& catalogue) {
         move();
     }
 
-    return false; // Don't explore indexes, etc. We have already moved them away...
+    return false;  // Don't explore indexes, etc. We have already moved them away...
 }
 
 void TocMoveVisitor::move() {
@@ -115,20 +112,18 @@ void TocMoveVisitor::move() {
     store_.moveTo(catalogue_.key(), catalogue_.config(), dest_, queue_);
 
     eckit::PathName destPath = dest_.path();
-    for (const eckit::PathName& root: CatalogueRootManager(catalogue_.config()).canMoveToRoots(catalogue_.key())) {
+    for (const eckit::PathName& root : CatalogueRootManager(catalogue_.config()).canMoveToRoots(catalogue_.key())) {
         if (root.sameAs(destPath)) {
             eckit::PathName dest_db = destPath / catalogue_.basePath().baseName(true);
 
-            if(!dest_db.exists()) {
+            if (!dest_db.exists()) {
                 dest_db.mkdir();
             }
-            
+
             DIR* dirp = ::opendir(catalogue_.basePath().c_str());
             struct dirent* dp;
             while ((dp = readdir(dirp)) != NULL) {
-                if (strstr( dp->d_name, ".index") ||
-                    strstr( dp->d_name, "toc.") ||
-                    strstr( dp->d_name, "schema")) {
+                if (strstr(dp->d_name, ".index") || strstr(dp->d_name, "toc.") || strstr(dp->d_name, "schema")) {
 
                     FileCopy fileCopy(catalogue_.basePath(), dest_db, dp->d_name);
                     queue_.emplace(fileCopy);
@@ -141,8 +136,7 @@ void TocMoveVisitor::move() {
 
             dirp = ::opendir(catalogue_.basePath().c_str());
             while ((dp = readdir(dirp)) != NULL) {
-                if (strstr( dp->d_name, ".lock") ||
-                    strstr( dp->d_name, "duplicates.allow")) {
+                if (strstr(dp->d_name, ".lock") || strstr(dp->d_name, "duplicates.allow")) {
 
                     FileCopy fileCopy(catalogue_.basePath(), dest_db, dp->d_name);
                     queue_.emplace(fileCopy);
@@ -157,4 +151,4 @@ void TocMoveVisitor::move() {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
