@@ -15,21 +15,21 @@
 #ifndef fdb5_TocDbStats_H
 #define fdb5_TocDbStats_H
 
-#include <set>
-#include <map>
 #include <iosfwd>
+#include <map>
+#include <set>
 
 #include "eckit/filesystem/PathName.h"
 
-#include "fdb5/database/DbStats.h"
-#include "fdb5/database/IndexStats.h"
 #include "fdb5/database/DataStats.h"
-#include "fdb5/database/StatsReportVisitor.h"
+#include "fdb5/database/DbStats.h"
 #include "fdb5/database/Index.h"
+#include "fdb5/database/IndexStats.h"
+#include "fdb5/database/StatsReportVisitor.h"
 #include "fdb5/toc/TocCatalogueReader.h"
 
-#include <unordered_set>
 #include <unordered_map>
+#include <unordered_set>
 
 namespace fdb5 {
 
@@ -58,22 +58,22 @@ public:
     size_t adoptedFilesCount_;
     size_t indexFilesCount_;
 
-    TocDbStats& operator+= (const TocDbStats& rhs);
+    TocDbStats& operator+=(const TocDbStats& rhs);
 
     void add(const DbStatsContent&) override;
 
-    void report(std::ostream &out, const char* indent) const override;
+    void report(std::ostream& out, const char* indent) const override;
 
-public: // For Streamable
+public:  // For Streamable
 
-    static const eckit::ClassSpec&  classSpec() { return classSpec_;}
+    static const eckit::ClassSpec& classSpec() { return classSpec_; }
 
-protected: // For Streamable
+protected:  // For Streamable
 
     void encode(eckit::Stream&) const override;
     const eckit::ReanimatorBase& reanimator() const override { return reanimator_; }
 
-    static eckit::ClassSpec                 classSpec_;
+    static eckit::ClassSpec classSpec_;
     static eckit::Reanimator<TocDbStats> reanimator_;
 };
 
@@ -99,28 +99,40 @@ public:
     size_t fieldsSize() const override { return fieldsSize_; }
     size_t duplicatesSize() const override { return duplicatesSize_; }
 
-    size_t addFieldsCount(size_t i) override { fieldsCount_ += i; return fieldsCount_; }
-    size_t addDuplicatesCount(size_t i) override { duplicatesCount_ += i; return duplicatesCount_; }
+    size_t addFieldsCount(size_t i) override {
+        fieldsCount_ += i;
+        return fieldsCount_;
+    }
+    size_t addDuplicatesCount(size_t i) override {
+        duplicatesCount_ += i;
+        return duplicatesCount_;
+    }
 
-    size_t addFieldsSize(size_t i) override { fieldsSize_ += i; return fieldsSize_; }
-    size_t addDuplicatesSize(size_t i) override { duplicatesSize_ += i; return duplicatesSize_; }
+    size_t addFieldsSize(size_t i) override {
+        fieldsSize_ += i;
+        return fieldsSize_;
+    }
+    size_t addDuplicatesSize(size_t i) override {
+        duplicatesSize_ += i;
+        return duplicatesSize_;
+    }
 
-    TocIndexStats& operator+= (const TocIndexStats& rhs);
+    TocIndexStats& operator+=(const TocIndexStats& rhs);
 
     void add(const IndexStatsContent&) override;
 
-    void report(std::ostream &out, const char* indent = "") const override;
+    void report(std::ostream& out, const char* indent = "") const override;
 
-public: // For Streamable
+public:  // For Streamable
 
-    static const eckit::ClassSpec&  classSpec() { return classSpec_;}
+    static const eckit::ClassSpec& classSpec() { return classSpec_; }
 
-protected: // For Streamable
+protected:  // For Streamable
 
     void encode(eckit::Stream&) const override;
     const eckit::ReanimatorBase& reanimator() const override { return reanimator_; }
 
-    static eckit::ClassSpec                 classSpec_;
+    static eckit::ClassSpec classSpec_;
     static eckit::Reanimator<TocIndexStats> reanimator_;
 };
 
@@ -137,11 +149,11 @@ public:
     std::set<eckit::PathName> activeDataFiles_;
     std::map<eckit::PathName, size_t> dataUsage_;
 
-    TocDataStats& operator+= (const TocDataStats& rhs);
+    TocDataStats& operator+=(const TocDataStats& rhs);
 
     virtual void add(const DataStatsContent&);
 
-    virtual void report(std::ostream &out, const char* indent) const;
+    virtual void report(std::ostream& out, const char* indent) const;
 };
 
 
@@ -151,13 +163,13 @@ public:
 class TocStatsReportVisitor : public virtual StatsReportVisitor {
 public:
 
-    TocStatsReportVisitor(const TocCatalogue& catalogue, bool includeReferenced=true);
+    TocStatsReportVisitor(const TocCatalogue& catalogue, bool includeReferenced = true);
     ~TocStatsReportVisitor() override;
 
     IndexStats indexStatistics() const override;
-    DbStats    dbStatistics() const override;
+    DbStats dbStatistics() const override;
 
-private: // methods
+private:  // methods
 
     bool visitDatabase(const Catalogue& catalogue) override;
     void visitDatum(const Field& field, const std::string& keyFingerprint) override;
@@ -168,7 +180,7 @@ private: // methods
     void catalogueComplete(const Catalogue& catalogue) override;
 
 
-protected: // members
+protected:  // members
 
     eckit::PathName directory_;
 
@@ -196,6 +208,6 @@ protected: // members
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
