@@ -32,9 +32,8 @@ void TypeParam::getValues(const metkit::mars::MarsRequest& request, const std::s
                           eckit::StringList& values, const Notifier& wind, const CatalogueReader* cat) const {
     ASSERT(cat);
 
-    eckit::DenseSet<std::string> ax;
-
-    cat->axis(keyword, ax);
+    auto ax = cat->axis(keyword);
+    ASSERT(ax);
 
     eckit::StringList us;
 
@@ -44,7 +43,7 @@ void TypeParam::getValues(const metkit::mars::MarsRequest& request, const std::s
     std::copy(us.begin(), us.end(), std::back_inserter(user));
 
     std::vector<Param> axis;
-    std::copy(ax.begin(), ax.end(), std::back_inserter(axis));
+    std::copy(ax->get().begin(), ax->get().end(), std::back_inserter(axis));
     std::sort(axis.begin(), axis.end());
 
     bool windConversion = false;
