@@ -20,8 +20,8 @@
 
 #include "metkit/mars/TypeAny.h"
 
-#include "fdb5/config/Config.h"
 #include "fdb5/api/helpers/FDBToolRequest.h"
+#include "fdb5/config/Config.h"
 
 #include "ApiSpy.h"
 
@@ -53,13 +53,13 @@ fdb5::Config defaultConfig() {
 
     fdb5::Config cfg;
     cfg.set("type", "dist");
-    cfg.set("lanes", { cfg_od, cfg_rd1, cfg_rd2 });
+    cfg.set("lanes", {cfg_od, cfg_rd1, cfg_rd2});
 
     return cfg;
 }
 
 
-CASE( "archives_distributed_according_to_dist" ) {
+CASE("archives_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -84,7 +84,7 @@ CASE( "archives_distributed_according_to_dist" ) {
     std::vector<int> data = {1, 2, 3, 4, 5};
 
     const int nflush = 5;
-    const int narch = 5;
+    const int narch  = 5;
 
     int flush_count = 0;
 
@@ -96,9 +96,9 @@ CASE( "archives_distributed_according_to_dist" ) {
             k.set("f", eckit::Translator<int, std::string>()(f));
             k.set("a", eckit::Translator<int, std::string>()(a));
 
-            data.assign(data.size(), 100*f + a);
+            data.assign(data.size(), 100 * f + a);
 
-            size_t len = data.size()*sizeof(int);
+            size_t len = data.size() * sizeof(int);
 
             fdb.archive(k, data.data(), len);
 
@@ -108,7 +108,7 @@ CASE( "archives_distributed_according_to_dist" ) {
 
         fdb.flush();
 
-        EXPECT(spy1.counts().flush + spy2.counts().flush + spy3.counts().flush <= flush_count+3);
+        EXPECT(spy1.counts().flush + spy2.counts().flush + spy3.counts().flush <= flush_count + 3);
 
         flush_count = (spy1.counts().flush + spy2.counts().flush + spy3.counts().flush);
     }
@@ -130,7 +130,7 @@ CASE( "archives_distributed_according_to_dist" ) {
 }
 
 
-CASE( "retrieves_distributed_according_to_dist" ) {
+CASE("retrieves_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -201,7 +201,7 @@ CASE( "retrieves_distributed_according_to_dist" ) {
     }
 }
 
-CASE( "lists_distributed_according_to_dist" ) {
+CASE("lists_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -268,7 +268,7 @@ CASE( "lists_distributed_according_to_dist" ) {
 }
 
 
-CASE( "dump_distributed_according_to_dist" ) {
+CASE("dump_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -334,7 +334,7 @@ CASE( "dump_distributed_according_to_dist" ) {
     }
 }
 
-CASE( "status_distributed_according_to_dist" ) {
+CASE("status_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -401,7 +401,7 @@ CASE( "status_distributed_according_to_dist" ) {
 }
 
 
-CASE( "wipe_distributed_according_to_dist" ) {
+CASE("wipe_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -468,7 +468,7 @@ CASE( "wipe_distributed_according_to_dist" ) {
 }
 
 
-CASE( "purge_distributed_according_to_dist" ) {
+CASE("purge_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -535,7 +535,7 @@ CASE( "purge_distributed_according_to_dist" ) {
 }
 
 
-CASE( "stats_distributed_according_to_dist" ) {
+CASE("stats_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -602,7 +602,7 @@ CASE( "stats_distributed_according_to_dist" ) {
 }
 
 
-CASE( "control_distributed_according_to_dist" ) {
+CASE("control_distributed_according_to_dist") {
 
     // Build FDB from default config
 
@@ -614,15 +614,15 @@ CASE( "control_distributed_according_to_dist" ) {
 
     // Do some archiving
 
-    fdb.control(fdb5::FDBToolRequest::requestsFromString("class=od,expver=xxxx")[0],
-                fdb5::ControlAction::Disable, fdb5::ControlIdentifiers(fdb5::ControlIdentifier::List));
+    fdb.control(fdb5::FDBToolRequest::requestsFromString("class=od,expver=xxxx")[0], fdb5::ControlAction::Disable,
+                fdb5::ControlIdentifiers(fdb5::ControlIdentifier::List));
 
     EXPECT(spy1.counts().control == 1);
     EXPECT(spy2.counts().control == 1);
     EXPECT(spy3.counts().control == 1);
 
-    fdb.control(fdb5::FDBToolRequest::requestsFromString("class=rd,expver=xxxx")[0],
-                fdb5::ControlAction::Disable, fdb5::ControlIdentifiers(fdb5::ControlIdentifier::Wipe));
+    fdb.control(fdb5::FDBToolRequest::requestsFromString("class=rd,expver=xxxx")[0], fdb5::ControlAction::Disable,
+                fdb5::ControlIdentifiers(fdb5::ControlIdentifier::Wipe));
 
     EXPECT(spy1.counts().control == 2);
     EXPECT(spy2.counts().control == 2);
@@ -631,8 +631,8 @@ CASE( "control_distributed_according_to_dist" ) {
     // Under specified - matches nothing. Requests halted at this point, as FDB retrieves need
     // to be fully specified
 
-    fdb.control(fdb5::FDBToolRequest::requestsFromString("class=rd,expver=zzzz")[0],
-                fdb5::ControlAction::Enable, fdb5::ControlIdentifiers(fdb5::ControlIdentifier::Retrieve));
+    fdb.control(fdb5::FDBToolRequest::requestsFromString("class=rd,expver=zzzz")[0], fdb5::ControlAction::Enable,
+                fdb5::ControlIdentifiers(fdb5::ControlIdentifier::Retrieve));
 
     EXPECT(spy1.counts().control == 3);
     EXPECT(spy2.counts().control == 3);
@@ -640,8 +640,8 @@ CASE( "control_distributed_according_to_dist" ) {
 
     //// Now match all the rd lanes
 
-    fdb.control(fdb5::FDBToolRequest::requestsFromString("class=rd")[0],
-                fdb5::ControlAction::Enable, fdb5::ControlIdentifiers(fdb5::ControlIdentifier::Archive));
+    fdb.control(fdb5::FDBToolRequest::requestsFromString("class=rd")[0], fdb5::ControlAction::Enable,
+                fdb5::ControlIdentifiers(fdb5::ControlIdentifier::Archive));
 
     EXPECT(spy1.counts().control == 4);
     EXPECT(spy2.counts().control == 4);
@@ -649,8 +649,8 @@ CASE( "control_distributed_according_to_dist" ) {
 
     // Explicitly match everything
 
-    fdb.control(fdb5::FDBToolRequest({}, true),
-                fdb5::ControlAction::Disable, fdb5::ControlIdentifiers(fdb5::ControlIdentifier::List));
+    fdb.control(fdb5::FDBToolRequest({}, true), fdb5::ControlAction::Disable,
+                fdb5::ControlIdentifiers(fdb5::ControlIdentifier::List));
 
     EXPECT(spy1.counts().control == 5);
     EXPECT(spy2.counts().control == 5);
@@ -676,7 +676,6 @@ CASE( "control_distributed_according_to_dist" ) {
 }  // namespace test
 }  // namespace fdb
 
-int main(int argc, char **argv)
-{
-    return run_tests ( argc, argv );
+int main(int argc, char** argv) {
+    return run_tests(argc, argv);
 }
