@@ -351,8 +351,13 @@ CASE("DaosContainer, DaosArray and DaosKeyValue") {
         EXPECT(nkv.has("test_key_4"));
         std::vector<std::string> keys = kv.keys();
         EXPECT(keys.size() == 2);
-        EXPECT(keys[0] == "test_key_3");
-        EXPECT(keys[1] == "test_key_4");
+        if (keys[0] == "test_key_3") {
+            EXPECT(keys[1] == "test_key_4");
+        }
+        else {
+            EXPECT(keys[0] == "test_key_4");
+            EXPECT(keys[1] == "test_key_3");
+        }
     }
 
     SECTION("DaosHandle write, append and read") {
